You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@arrow.apache.org by GitBox <gi...@apache.org> on 2021/06/23 01:17:45 UTC
[GitHub] [arrow-datafusion] Jimexist commented on pull request #569: Use repartition in window functions to speed up
Jimexist commented on pull request #569:
URL: https://github.com/apache/arrow-datafusion/pull/569#issuecomment-866448201
> Nice, almost 5 times improvement for some queries!
>
> But do those have to do with the changes wrt sort or with regards to partition by?
I don't expect that much of an improvement. let me redo the benchmark after #573 is merged.
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
For queries about this service, please contact Infrastructure at:
users@infra.apache.org